# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [Unreleased]

## [0.0.5] - 2020-08-05

### Added
 * Nothing

### Changed
 * Correct includes problem with wheels

### Removed
 * Nothing

## [0.0.4] - 2020-08-05

### Added
Nothing

### Changed
 * Include alm plugins files into package

### Removed
 * Nothing

## [0.0.3] - 2020-08-05

### Added
Nothing

### Changed
 * Include json plugins files into package

### Removed
 * Nothing

## [0.0.2] - 2020-08-05

### Added
 * Python projet skeleton (setuptools, Makefile, bumpversion)
 * CLI with Argparse
 * Automatic creation of folders in user homedir
 * osiris system set
 * osiris system get
 * osiris system add
 * osiris system remove
 * osiris system list
 * osiris object introspect
 * osiris system introspect
 * Verbose option

### Changed
 * Systems data moved in user homedir
 * Flake8 compliance (with CI check)

### Removed
Nothing

## [0.0.1] - 2020-07-20

### Added
 * Skeleton (nothing operationnal)

### Changed
Nothing

### Removed
Nothing
